/*
 * Copyright 2010 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
/*
 * This file was generated.
 *  with google-apis-code-generator 1.3.0 (build: 2013-04-29 14:08:19 UTC)
 *  on 2013-05-01 at 03:02:59 UTC 
 */

package com.google.api.services.tasks;

import com.google.api.client.googleapis.GoogleUtils;
import com.google.api.client.googleapis.services.AbstractGoogleClientRequest;
import com.google.api.client.googleapis.services.GoogleClientRequestInitializer;
import com.google.api.client.googleapis.services.json.AbstractGoogleJsonClient;
import com.google.api.client.http.HttpRequestInitializer;
import com.google.api.client.http.HttpTransport;
import com.google.api.client.json.JsonFactory;
import com.google.api.client.json.JsonObjectParser;
import com.google.api.client.json.JsonString;
import com.google.common.base.Preconditions;

/**
 * Service definition for Tasks (v1).
 *
 * <p>
 * Lets you manage your tasks and task lists.
 * </p>
 *
 * <p>
 * For more information about this service, see the
 * <a href="https://developers.google.com/google-apps/tasks/firstapp" target="_blank">API Documentation</a>
 * </p>
 *
 * <p>
 * This service uses {@link TasksRequestInitializer} to initialize global parameters via its
 * {@link Builder}.
 * </p>
 *
 * <p>
 * Upgrade warning: this class now extends {@link AbstractGoogleJsonClient}, whereas in prior
 * version 1.8 it extended {@link com.google.api.client.googleapis.services.GoogleClient}.
 * </p>
 *
 * @since 1.3
 * @author Google, Inc.
 */
@SuppressWarnings("javadoc")
public class Tasks extends AbstractGoogleJsonClient {

  // Note: Leave this static initializer at the top of the file.
  static {
    Preconditions.checkState(GoogleUtils.VERSION.equals("1.13.2-beta"),
        "You are currently running with version %s of google-api-client. " +
        "You need version 1.13.2-beta of google-api-client to run version " +
        "1.13.2-beta of the Tasks API library.", GoogleUtils.VERSION);
  }

  /**
   * The default encoded root URL of the service. This is determined when the library is generated
   * and normally should not be changed.
   *
   * @since 1.7
   */
  public static final String DEFAULT_ROOT_URL = "https://www.googleapis.com/";

  /**
   * The default encoded service path of the service. This is determined when the library is
   * generated and normally should not be changed.
   *
   * @since 1.7
   */
  public static final String DEFAULT_SERVICE_PATH = "tasks/v1/";

  /**
   * The default encoded base URL of the service. This is determined when the library is generated
   * and normally should not be changed.
   * @deprecated (scheduled to be removed in 1.13)
   */
  @Deprecated
  public static final String DEFAULT_BASE_URL = DEFAULT_ROOT_URL + DEFAULT_SERVICE_PATH;

  /**
   * Constructor.
   *
   * <p>
   * Use {@link Builder} if you need to specify any of the optional parameters.
   * </p>
   *
   * @param transport HTTP transport
   * @param jsonFactory JSON factory
   * @param httpRequestInitializer HTTP request initializer or {@code null} for none
   * @since 1.7
   */
  public Tasks(HttpTransport transport, JsonFactory jsonFactory,
      HttpRequestInitializer httpRequestInitializer) {
    super(transport,
        jsonFactory,
        DEFAULT_ROOT_URL,
        DEFAULT_SERVICE_PATH,
        httpRequestInitializer,
        false);
  }

  /**
   * @param transport HTTP transport
   * @param httpRequestInitializer HTTP request initializer or {@code null} for none
   * @param rootUrl root URL of the service
   * @param servicePath service path
   * @param jsonObjectParser JSON object parser
   * @param googleClientRequestInitializer Google request initializer or {@code null} for none
   * @param applicationName application name to be sent in the User-Agent header of requests or
   *        {@code null} for none
   * @param suppressPatternChecks whether discovery pattern checks should be suppressed on required
   *        parameters
   */
  Tasks(HttpTransport transport,
      HttpRequestInitializer httpRequestInitializer,
      String rootUrl,
      String servicePath,
      JsonObjectParser jsonObjectParser,
      GoogleClientRequestInitializer googleClientRequestInitializer,
      String applicationName,
      boolean suppressPatternChecks) {
    super(transport,
        httpRequestInitializer,
        rootUrl,
        servicePath,
        jsonObjectParser,
        googleClientRequestInitializer,
        applicationName,
        suppressPatternChecks);
  }

  @Override
  protected void initialize(AbstractGoogleClientRequest<?> httpClientRequest) throws java.io.IOException {
    super.initialize(httpClientRequest);
  }

  /**
   * An accessor for creating requests from the Tasklists collection.
   *
   * <p>The typical use is:</p>
   * <pre>
   *   {@code Tasks tasks = new Tasks(...);}
   *   {@code Tasks.Tasklists.List request = tasks.tasklists().list(parameters ...)}
   * </pre>
   *
   * @return the resource collection
   */
  public Tasklists tasklists() {
    return new Tasklists();
  }

  /**
   * The "tasklists" collection of methods.
   */
  public class Tasklists {

    /**
     * Deletes the authenticated user's specified task list.
     *
     * Create a request for the method "tasklists.delete".
     *
     * This request holds the parameters needed by the the tasks server.  After setting any optional
     * parameters, call the {@link Delete#execute()} method to invoke the remote operation.
     *
     * @param tasklist Task list identifier.
     * @return the request
     */
    public Delete delete(String tasklist) throws java.io.IOException {
      Delete result = new Delete(tasklist);
      initialize(result);
      return result;
    }

    public class Delete extends TasksRequest<Void> {

      private static final String REST_PATH = "users/@me/lists/{tasklist}";

      /**
       * Deletes the authenticated user's specified task list.
       *
       * Create a request for the method "tasklists.delete".
       *
       * This request holds the parameters needed by the the tasks server.  After setting any optional
       * parameters, call the {@link Delete#execute()} method to invoke the remote operation. <p> {@link
       * Delete#initialize(AbstractGoogleClientRequest)} must be called to initialize this instance
       * immediately after invoking the constructor. </p>
       *
       * @param tasklist Task list identifier.
       * @since 1.13
       */
      protected Delete(String tasklist) {
        super(Tasks.this, "DELETE", REST_PATH, null, Void.class);
        this.tasklist = Preconditions.checkNotNull(tasklist, "Required parameter tasklist must be specified.");
      }

      @Override
      public Delete setAlt(String alt) {
        return (Delete) super.setAlt(alt);
      }

      @Override
      public Delete setFields(String fields) {
        return (Delete) super.setFields(fields);
      }

      @Override
      public Delete setKey(String key) {
        return (Delete) super.setKey(key);
      }

      @Override
      public Delete setOauthToken(String oauthToken) {
        return (Delete) super.setOauthToken(oauthToken);
      }

      @Override
      public Delete setPrettyPrint(Boolean prettyPrint) {
        return (Delete) super.setPrettyPrint(prettyPrint);
      }

      @Override
      public Delete setQuotaUser(String quotaUser) {
        return (Delete) super.setQuotaUser(quotaUser);
      }

      @Override
      public Delete setUserIp(String userIp) {
        return (Delete) super.setUserIp(userIp);
      }

      /** Task list identifier. */
      @com.google.api.client.util.Key
      private String tasklist;

      /** Task list identifier.
       */
      public String getTasklist() {
        return tasklist;
      }

      /** Task list identifier. */
      public Delete setTasklist(String tasklist) {
        this.tasklist = tasklist;
        return this;
      }

    }
    /**
     * Returns the authenticated user's specified task list.
     *
     * Create a request for the method "tasklists.get".
     *
     * This request holds the parameters needed by the the tasks server.  After setting any optional
     * parameters, call the {@link Get#execute()} method to invoke the remote operation.
     *
     * @param tasklist Task list identifier.
     * @return the request
     */
    public Get get(String tasklist) throws java.io.IOException {
      Get result = new Get(tasklist);
      initialize(result);
      return result;
    }

    public class Get extends TasksRequest<com.google.api.services.tasks.model.TaskList> {

      private static final String REST_PATH = "users/@me/lists/{tasklist}";

      /**
       * Returns the authenticated user's specified task list.
       *
       * Create a request for the method "tasklists.get".
       *
       * This request holds the parameters needed by the the tasks server.  After setting any optional
       * parameters, call the {@link Get#execute()} method to invoke the remote operation. <p> {@link
       * Get#initialize(AbstractGoogleClientRequest)} must be called to initialize this instance
       * immediately after invoking the constructor. </p>
       *
       * @param tasklist Task list identifier.
       * @since 1.13
       */
      protected Get(String tasklist) {
        super(Tasks.this, "GET", REST_PATH, null, com.google.api.services.tasks.model.TaskList.class);
        this.tasklist = Preconditions.checkNotNull(tasklist, "Required parameter tasklist must be specified.");
      }

      @Override
      public com.google.api.client.http.HttpResponse executeUsingHead() throws java.io.IOException {
        return super.executeUsingHead();
      }

      @Override
      public com.google.api.client.http.HttpRequest buildHttpRequestUsingHead() throws java.io.IOException {
        return super.buildHttpRequestUsingHead();
      }

      @Override
      public Get setAlt(String alt) {
        return (Get) super.setAlt(alt);
      }

      @Override
      public Get setFields(String fields) {
        return (Get) super.setFields(fields);
      }

      @Override
      public Get setKey(String key) {
        return (Get) super.setKey(key);
      }

      @Override
      public Get setOauthToken(String oauthToken) {
        return (Get) super.setOauthToken(oauthToken);
      }

      @Override
      public Get setPrettyPrint(Boolean prettyPrint) {
        return (Get) super.setPrettyPrint(prettyPrint);
      }

      @Override
      public Get setQuotaUser(String quotaUser) {
        return (Get) super.setQuotaUser(quotaUser);
      }

      @Override
      public Get setUserIp(String userIp) {
        return (Get) super.setUserIp(userIp);
      }

      /** Task list identifier. */
      @com.google.api.client.util.Key
      private String tasklist;

      /** Task list identifier.
       */
      public String getTasklist() {
        return tasklist;
      }

      /** Task list identifier. */
      public Get setTasklist(String tasklist) {
        this.tasklist = tasklist;
        return this;
      }

    }
    /**
     * Creates a new task list and adds it to the authenticated user's task lists.
     *
     * Create a request for the method "tasklists.insert".
     *
     * This request holds the parameters needed by the the tasks server.  After setting any optional
     * parameters, call the {@link Insert#execute()} method to invoke the remote operation.
     *
     * @param content the {@link com.google.api.services.tasks.model.TaskList}
     * @return the request
     */
    public Insert insert(com.google.api.services.tasks.model.TaskList content) throws java.io.IOException {
      Insert result = new Insert(content);
      initialize(result);
      return result;
    }

    public class Insert extends TasksRequest<com.google.api.services.tasks.model.TaskList> {

      private static final String REST_PATH = "users/@me/lists";

      /**
       * Creates a new task list and adds it to the authenticated user's task lists.
       *
       * Create a request for the method "tasklists.insert".
       *
       * This request holds the parameters needed by the the tasks server.  After setting any optional
       * parameters, call the {@link Insert#execute()} method to invoke the remote operation. <p> {@link
       * Insert#initialize(AbstractGoogleClientRequest)} must be called to initialize this instance
       * immediately after invoking the constructor. </p>
       *
       * @param content the {@link com.google.api.services.tasks.model.TaskList}
       * @since 1.13
       */
      protected Insert(com.google.api.services.tasks.model.TaskList content) {
        super(Tasks.this, "POST", REST_PATH, content, com.google.api.services.tasks.model.TaskList.class);
      }

      @Override
      public Insert setAlt(String alt) {
        return (Insert) super.setAlt(alt);
      }

      @Override
      public Insert setFields(String fields) {
        return (Insert) super.setFields(fields);
      }

      @Override
      public Insert setKey(String key) {
        return (Insert) super.setKey(key);
      }

      @Override
      public Insert setOauthToken(String oauthToken) {
        return (Insert) super.setOauthToken(oauthToken);
      }

      @Override
      public Insert setPrettyPrint(Boolean prettyPrint) {
        return (Insert) super.setPrettyPrint(prettyPrint);
      }

      @Override
      public Insert setQuotaUser(String quotaUser) {
        return (Insert) super.setQuotaUser(quotaUser);
      }

      @Override
      public Insert setUserIp(String userIp) {
        return (Insert) super.setUserIp(userIp);
      }

    }
    /**
     * Returns all the authenticated user's task lists.
     *
     * Create a request for the method "tasklists.list".
     *
     * This request holds the parameters needed by the the tasks server.  After setting any optional
     * parameters, call the {@link List#execute()} method to invoke the remote operation.
     *
     * @return the request
     */
    public List list() throws java.io.IOException {
      List result = new List();
      initialize(result);
      return result;
    }

    public class List extends TasksRequest<com.google.api.services.tasks.model.TaskLists> {

      private static final String REST_PATH = "users/@me/lists";

      /**
       * Returns all the authenticated user's task lists.
       *
       * Create a request for the method "tasklists.list".
       *
       * This request holds the parameters needed by the the tasks server.  After setting any optional
       * parameters, call the {@link List#execute()} method to invoke the remote operation. <p> {@link
       * List#initialize(AbstractGoogleClientRequest)} must be called to initialize this instance
       * immediately after invoking the constructor. </p>
       *
       * @since 1.13
       */
      protected List() {
        super(Tasks.this, "GET", REST_PATH, null, com.google.api.services.tasks.model.TaskLists.class);
      }

      @Override
      public com.google.api.client.http.HttpResponse executeUsingHead() throws java.io.IOException {
        return super.executeUsingHead();
      }

      @Override
      public com.google.api.client.http.HttpRequest buildHttpRequestUsingHead() throws java.io.IOException {
        return super.buildHttpRequestUsingHead();
      }

      @Override
      public List setAlt(String alt) {
        return (List) super.setAlt(alt);
      }

      @Override
      public List setFields(String fields) {
        return (List) super.setFields(fields);
      }

      @Override
      public List setKey(String key) {
        return (List) super.setKey(key);
      }

      @Override
      public List setOauthToken(String oauthToken) {
        return (List) super.setOauthToken(oauthToken);
      }

      @Override
      public List setPrettyPrint(Boolean prettyPrint) {
        return (List) super.setPrettyPrint(prettyPrint);
      }

      @Override
      public List setQuotaUser(String quotaUser) {
        return (List) super.setQuotaUser(quotaUser);
      }

      @Override
      public List setUserIp(String userIp) {
        return (List) super.setUserIp(userIp);
      }

      /** Token specifying the result page to return. Optional. */
      @com.google.api.client.util.Key
      private String pageToken;

      /** Token specifying the result page to return. Optional.
       */
      public String getPageToken() {
        return pageToken;
      }

      /** Token specifying the result page to return. Optional. */
      public List setPageToken(String pageToken) {
        this.pageToken = pageToken;
        return this;
      }

      /** Maximum number of task lists returned on one page. Optional. The default is 100. */
      @com.google.api.client.util.Key
      private Long maxResults;

      /** Maximum number of task lists returned on one page. Optional. The default is 100.
       */
      public Long getMaxResults() {
        return maxResults;
      }

      /** Maximum number of task lists returned on one page. Optional. The default is 100. */
      public List setMaxResults(Long maxResults) {
        this.maxResults = maxResults;
        return this;
      }

    }
    /**
     * Updates the authenticated user's specified task list. This method supports patch semantics.
     *
     * Create a request for the method "tasklists.patch".
     *
     * This request holds the parameters needed by the the tasks server.  After setting any optional
     * parameters, call the {@link Patch#execute()} method to invoke the remote operation.
     *
     * @param tasklist Task list identifier.
     * @param content the {@link com.google.api.services.tasks.model.TaskList}
     * @return the request
     */
    public Patch patch(String tasklist, com.google.api.services.tasks.model.TaskList content) throws java.io.IOException {
      Patch result = new Patch(tasklist, content);
      initialize(result);
      return result;
    }

    public class Patch extends TasksRequest<com.google.api.services.tasks.model.TaskList> {

      private static final String REST_PATH = "users/@me/lists/{tasklist}";

      /**
       * Updates the authenticated user's specified task list. This method supports patch semantics.
       *
       * Create a request for the method "tasklists.patch".
       *
       * This request holds the parameters needed by the the tasks server.  After setting any optional
       * parameters, call the {@link Patch#execute()} method to invoke the remote operation. <p> {@link
       * Patch#initialize(AbstractGoogleClientRequest)} must be called to initialize this instance
       * immediately after invoking the constructor. </p>
       *
       * @param tasklist Task list identifier.
       * @param content the {@link com.google.api.services.tasks.model.TaskList}
       * @since 1.13
       */
      protected Patch(String tasklist, com.google.api.services.tasks.model.TaskList content) {
        super(Tasks.this, "PATCH", REST_PATH, content, com.google.api.services.tasks.model.TaskList.class);
        this.tasklist = Preconditions.checkNotNull(tasklist, "Required parameter tasklist must be specified.");
      }

      @Override
      public Patch setAlt(String alt) {
        return (Patch) super.setAlt(alt);
      }

      @Override
      public Patch setFields(String fields) {
        return (Patch) super.setFields(fields);
      }

      @Override
      public Patch setKey(String key) {
        return (Patch) super.setKey(key);
      }

      @Override
      public Patch setOauthToken(String oauthToken) {
        return (Patch) super.setOauthToken(oauthToken);
      }

      @Override
      public Patch setPrettyPrint(Boolean prettyPrint) {
        return (Patch) super.setPrettyPrint(prettyPrint);
      }

      @Override
      public Patch setQuotaUser(String quotaUser) {
        return (Patch) super.setQuotaUser(quotaUser);
      }

      @Override
      public Patch setUserIp(String userIp) {
        return (Patch) super.setUserIp(userIp);
      }

      /** Task list identifier. */
      @com.google.api.client.util.Key
      private String tasklist;

      /** Task list identifier.
       */
      public String getTasklist() {
        return tasklist;
      }

      /** Task list identifier. */
      public Patch setTasklist(String tasklist) {
        this.tasklist = tasklist;
        return this;
      }

    }
    /**
     * Updates the authenticated user's specified task list.
     *
     * Create a request for the method "tasklists.update".
     *
     * This request holds the parameters needed by the the tasks server.  After setting any optional
     * parameters, call the {@link Update#execute()} method to invoke the remote operation.
     *
     * @param tasklist Task list identifier.
     * @param content the {@link com.google.api.services.tasks.model.TaskList}
     * @return the request
     */
    public Update update(String tasklist, com.google.api.services.tasks.model.TaskList content) throws java.io.IOException {
      Update result = new Update(tasklist, content);
      initialize(result);
      return result;
    }

    public class Update extends TasksRequest<com.google.api.services.tasks.model.TaskList> {

      private static final String REST_PATH = "users/@me/lists/{tasklist}";

      /**
       * Updates the authenticated user's specified task list.
       *
       * Create a request for the method "tasklists.update".
       *
       * This request holds the parameters needed by the the tasks server.  After setting any optional
       * parameters, call the {@link Update#execute()} method to invoke the remote operation. <p> {@link
       * Update#initialize(AbstractGoogleClientRequest)} must be called to initialize this instance
       * immediately after invoking the constructor. </p>
       *
       * @param tasklist Task list identifier.
       * @param content the {@link com.google.api.services.tasks.model.TaskList}
       * @since 1.13
       */
      protected Update(String tasklist, com.google.api.services.tasks.model.TaskList content) {
        super(Tasks.this, "PUT", REST_PATH, content, com.google.api.services.tasks.model.TaskList.class);
        this.tasklist = Preconditions.checkNotNull(tasklist, "Required parameter tasklist must be specified.");
      }

      @Override
      public Update setAlt(String alt) {
        return (Update) super.setAlt(alt);
      }

      @Override
      public Update setFields(String fields) {
        return (Update) super.setFields(fields);
      }

      @Override
      public Update setKey(String key) {
        return (Update) super.setKey(key);
      }

      @Override
      public Update setOauthToken(String oauthToken) {
        return (Update) super.setOauthToken(oauthToken);
      }

      @Override
      public Update setPrettyPrint(Boolean prettyPrint) {
        return (Update) super.setPrettyPrint(prettyPrint);
      }

      @Override
      public Update setQuotaUser(String quotaUser) {
        return (Update) super.setQuotaUser(quotaUser);
      }

      @Override
      public Update setUserIp(String userIp) {
        return (Update) super.setUserIp(userIp);
      }

      /** Task list identifier. */
      @com.google.api.client.util.Key
      private String tasklist;

      /** Task list identifier.
       */
      public String getTasklist() {
        return tasklist;
      }

      /** Task list identifier. */
      public Update setTasklist(String tasklist) {
        this.tasklist = tasklist;
        return this;
      }

    }

  }

  /**
   * An accessor for creating requests from the TasksOperations collection.
   *
   * <p>The typical use is:</p>
   * <pre>
   *   {@code Tasks tasks = new Tasks(...);}
   *   {@code Tasks.TasksOperations.List request = tasks.tasks().list(parameters ...)}
   * </pre>
   *
   * @return the resource collection
   */
  public TasksOperations tasks() {
    return new TasksOperations();
  }

  /**
   * The "tasks" collection of methods.
   */
  public class TasksOperations {

    /**
     * Clears all completed tasks from the specified task list. The affected tasks will be marked as
     * 'hidden' and no longer be returned by default when retrieving all tasks for a task list.
     *
     * Create a request for the method "tasks.clear".
     *
     * This request holds the parameters needed by the the tasks server.  After setting any optional
     * parameters, call the {@link Clear#execute()} method to invoke the remote operation.
     *
     * @param tasklist Task list identifier.
     * @return the request
     */
    public Clear clear(String tasklist) throws java.io.IOException {
      Clear result = new Clear(tasklist);
      initialize(result);
      return result;
    }

    public class Clear extends TasksRequest<Void> {

      private static final String REST_PATH = "lists/{tasklist}/clear";

      /**
       * Clears all completed tasks from the specified task list. The affected tasks will be marked as
       * 'hidden' and no longer be returned by default when retrieving all tasks for a task list.
       *
       * Create a request for the method "tasks.clear".
       *
       * This request holds the parameters needed by the the tasks server.  After setting any optional
       * parameters, call the {@link Clear#execute()} method to invoke the remote operation. <p> {@link
       * Clear#initialize(AbstractGoogleClientRequest)} must be called to initialize this instance
       * immediately after invoking the constructor. </p>
       *
       * @param tasklist Task list identifier.
       * @since 1.13
       */
      protected Clear(String tasklist) {
        super(Tasks.this, "POST", REST_PATH, null, Void.class);
        this.tasklist = Preconditions.checkNotNull(tasklist, "Required parameter tasklist must be specified.");
      }

      @Override
      public Clear setAlt(String alt) {
        return (Clear) super.setAlt(alt);
      }

      @Override
      public Clear setFields(String fields) {
        return (Clear) super.setFields(fields);
      }

      @Override
      public Clear setKey(String key) {
        return (Clear) super.setKey(key);
      }

      @Override
      public Clear setOauthToken(String oauthToken) {
        return (Clear) super.setOauthToken(oauthToken);
      }

      @Override
      public Clear setPrettyPrint(Boolean prettyPrint) {
        return (Clear) super.setPrettyPrint(prettyPrint);
      }

      @Override
      public Clear setQuotaUser(String quotaUser) {
        return (Clear) super.setQuotaUser(quotaUser);
      }

      @Override
      public Clear setUserIp(String userIp) {
        return (Clear) super.setUserIp(userIp);
      }

      /** Task list identifier. */
      @com.google.api.client.util.Key
      private String tasklist;

      /** Task list identifier.
       */
      public String getTasklist() {
        return tasklist;
      }

      /** Task list identifier. */
      public Clear setTasklist(String tasklist) {
        this.tasklist = tasklist;
        return this;
      }

    }
    /**
     * Deletes the specified task from the task list.
     *
     * Create a request for the method "tasks.delete".
     *
     * This request holds the parameters needed by the the tasks server.  After setting any optional
     * parameters, call the {@link Delete#execute()} method to invoke the remote operation.
     *
     * @param tasklist Task list identifier.
     * @param task Task identifier.
     * @return the request
     */
    public Delete delete(String tasklist, String task) throws java.io.IOException {
      Delete result = new Delete(tasklist, task);
      initialize(result);
      return result;
    }

    public class Delete extends TasksRequest<Void> {

      private static final String REST_PATH = "lists/{tasklist}/tasks/{task}";

      /**
       * Deletes the specified task from the task list.
       *
       * Create a request for the method "tasks.delete".
       *
       * This request holds the parameters needed by the the tasks server.  After setting any optional
       * parameters, call the {@link Delete#execute()} method to invoke the remote operation. <p> {@link
       * Delete#initialize(AbstractGoogleClientRequest)} must be called to initialize this instance
       * immediately after invoking the constructor. </p>
       *
       * @param tasklist Task list identifier.
       * @param task Task identifier.
       * @since 1.13
       */
      protected Delete(String tasklist, String task) {
        super(Tasks.this, "DELETE", REST_PATH, null, Void.class);
        this.tasklist = Preconditions.checkNotNull(tasklist, "Required parameter tasklist must be specified.");
        this.task = Preconditions.checkNotNull(task, "Required parameter task must be specified.");
      }

      @Override
      public Delete setAlt(String alt) {
        return (Delete) super.setAlt(alt);
      }

      @Override
      public Delete setFields(String fields) {
        return (Delete) super.setFields(fields);
      }

      @Override
      public Delete setKey(String key) {
        return (Delete) super.setKey(key);
      }

      @Override
      public Delete setOauthToken(String oauthToken) {
        return (Delete) super.setOauthToken(oauthToken);
      }

      @Override
      public Delete setPrettyPrint(Boolean prettyPrint) {
        return (Delete) super.setPrettyPrint(prettyPrint);
      }

      @Override
      public Delete setQuotaUser(String quotaUser) {
        return (Delete) super.setQuotaUser(quotaUser);
      }

      @Override
      public Delete setUserIp(String userIp) {
        return (Delete) super.setUserIp(userIp);
      }

      /** Task list identifier. */
      @com.google.api.client.util.Key
      private String tasklist;

      /** Task list identifier.
       */
      public String getTasklist() {
        return tasklist;
      }

      /** Task list identifier. */
      public Delete setTasklist(String tasklist) {
        this.tasklist = tasklist;
        return this;
      }

      /** Task identifier. */
      @com.google.api.client.util.Key
      private String task;

      /** Task identifier.
       */
      public String getTask() {
        return task;
      }

      /** Task identifier. */
      public Delete setTask(String task) {
        this.task = task;
        return this;
      }

    }
    /**
     * Returns the specified task.
     *
     * Create a request for the method "tasks.get".
     *
     * This request holds the parameters needed by the the tasks server.  After setting any optional
     * parameters, call the {@link Get#execute()} method to invoke the remote operation.
     *
     * @param tasklist Task list identifier.
     * @param task Task identifier.
     * @return the request
     */
    public Get get(String tasklist, String task) throws java.io.IOException {
      Get result = new Get(tasklist, task);
      initialize(result);
      return result;
    }

    public class Get extends TasksRequest<com.google.api.services.tasks.model.Task> {

      private static final String REST_PATH = "lists/{tasklist}/tasks/{task}";

      /**
       * Returns the specified task.
       *
       * Create a request for the method "tasks.get".
       *
       * This request holds the parameters needed by the the tasks server.  After setting any optional
       * parameters, call the {@link Get#execute()} method to invoke the remote operation. <p> {@link
       * Get#initialize(AbstractGoogleClientRequest)} must be called to initialize this instance
       * immediately after invoking the constructor. </p>
       *
       * @param tasklist Task list identifier.
       * @param task Task identifier.
       * @since 1.13
       */
      protected Get(String tasklist, String task) {
        super(Tasks.this, "GET", REST_PATH, null, com.google.api.services.tasks.model.Task.class);
        this.tasklist = Preconditions.checkNotNull(tasklist, "Required parameter tasklist must be specified.");
        this.task = Preconditions.checkNotNull(task, "Required parameter task must be specified.");
      }

      @Override
      public com.google.api.client.http.HttpResponse executeUsingHead() throws java.io.IOException {
        return super.executeUsingHead();
      }

      @Override
      public com.google.api.client.http.HttpRequest buildHttpRequestUsingHead() throws java.io.IOException {
        return super.buildHttpRequestUsingHead();
      }

      @Override
      public Get setAlt(String alt) {
        return (Get) super.setAlt(alt);
      }

      @Override
      public Get setFields(String fields) {
        return (Get) super.setFields(fields);
      }

      @Override
      public Get setKey(String key) {
        return (Get) super.setKey(key);
      }

      @Override
      public Get setOauthToken(String oauthToken) {
        return (Get) super.setOauthToken(oauthToken);
      }

      @Override
      public Get setPrettyPrint(Boolean prettyPrint) {
        return (Get) super.setPrettyPrint(prettyPrint);
      }

      @Override
      public Get setQuotaUser(String quotaUser) {
        return (Get) super.setQuotaUser(quotaUser);
      }

      @Override
      public Get setUserIp(String userIp) {
        return (Get) super.setUserIp(userIp);
      }

      /** Task list identifier. */
      @com.google.api.client.util.Key
      private String tasklist;

      /** Task list identifier.
       */
      public String getTasklist() {
        return tasklist;
      }

      /** Task list identifier. */
      public Get setTasklist(String tasklist) {
        this.tasklist = tasklist;
        return this;
      }

      /** Task identifier. */
      @com.google.api.client.util.Key
      private String task;

      /** Task identifier.
       */
      public String getTask() {
        return task;
      }

      /** Task identifier. */
      public Get setTask(String task) {
        this.task = task;
        return this;
      }

    }
    /**
     * Creates a new task on the specified task list.
     *
     * Create a request for the method "tasks.insert".
     *
     * This request holds the parameters needed by the the tasks server.  After setting any optional
     * parameters, call the {@link Insert#execute()} method to invoke the remote operation.
     *
     * @param tasklist Task list identifier.
     * @param content the {@link com.google.api.services.tasks.model.Task}
     * @return the request
     */
    public Insert insert(String tasklist, com.google.api.services.tasks.model.Task content) throws java.io.IOException {
      Insert result = new Insert(tasklist, content);
      initialize(result);
      return result;
    }

    public class Insert extends TasksRequest<com.google.api.services.tasks.model.Task> {

      private static final String REST_PATH = "lists/{tasklist}/tasks";

      /**
       * Creates a new task on the specified task list.
       *
       * Create a request for the method "tasks.insert".
       *
       * This request holds the parameters needed by the the tasks server.  After setting any optional
       * parameters, call the {@link Insert#execute()} method to invoke the remote operation. <p> {@link
       * Insert#initialize(AbstractGoogleClientRequest)} must be called to initialize this instance
       * immediately after invoking the constructor. </p>
       *
       * @param tasklist Task list identifier.
       * @param content the {@link com.google.api.services.tasks.model.Task}
       * @since 1.13
       */
      protected Insert(String tasklist, com.google.api.services.tasks.model.Task content) {
        super(Tasks.this, "POST", REST_PATH, content, com.google.api.services.tasks.model.Task.class);
        this.tasklist = Preconditions.checkNotNull(tasklist, "Required parameter tasklist must be specified.");
      }

      @Override
      public Insert setAlt(String alt) {
        return (Insert) super.setAlt(alt);
      }

      @Override
      public Insert setFields(String fields) {
        return (Insert) super.setFields(fields);
      }

      @Override
      public Insert setKey(String key) {
        return (Insert) super.setKey(key);
      }

      @Override
      public Insert setOauthToken(String oauthToken) {
        return (Insert) super.setOauthToken(oauthToken);
      }

      @Override
      public Insert setPrettyPrint(Boolean prettyPrint) {
        return (Insert) super.setPrettyPrint(prettyPrint);
      }

      @Override
      public Insert setQuotaUser(String quotaUser) {
        return (Insert) super.setQuotaUser(quotaUser);
      }

      @Override
      public Insert setUserIp(String userIp) {
        return (Insert) super.setUserIp(userIp);
      }

      /** Task list identifier. */
      @com.google.api.client.util.Key
      private String tasklist;

      /** Task list identifier.
       */
      public String getTasklist() {
        return tasklist;
      }

      /** Task list identifier. */
      public Insert setTasklist(String tasklist) {
        this.tasklist = tasklist;
        return this;
      }

      /**
     * Parent task identifier. If the task is created at the top level, this parameter is omitted.
     * Optional.
     */
      @com.google.api.client.util.Key
      private String parent;

      /** Parent task identifier. If the task is created at the top level, this parameter is omitted.
     Optional.
       */
      public String getParent() {
        return parent;
      }

      /**
     * Parent task identifier. If the task is created at the top level, this parameter is omitted.
     * Optional.
     */
      public Insert setParent(String parent) {
        this.parent = parent;
        return this;
      }

      /**
     * Previous sibling task identifier. If the task is created at the first position among its
     * siblings, this parameter is omitted. Optional.
     */
      @com.google.api.client.util.Key
      private String previous;

      /** Previous sibling task identifier. If the task is created at the first position among its siblings,
     this parameter is omitted. Optional.
       */
      public String getPrevious() {
        return previous;
      }

      /**
     * Previous sibling task identifier. If the task is created at the first position among its
     * siblings, this parameter is omitted. Optional.
     */
      public Insert setPrevious(String previous) {
        this.previous = previous;
        return this;
      }

    }
    /**
     * Returns all tasks in the specified task list.
     *
     * Create a request for the method "tasks.list".
     *
     * This request holds the parameters needed by the the tasks server.  After setting any optional
     * parameters, call the {@link List#execute()} method to invoke the remote operation.
     *
     * @param tasklist Task list identifier.
     * @return the request
     */
    public List list(String tasklist) throws java.io.IOException {
      List result = new List(tasklist);
      initialize(result);
      return result;
    }

    public class List extends TasksRequest<com.google.api.services.tasks.model.Tasks> {

      private static final String REST_PATH = "lists/{tasklist}/tasks";

      /**
       * Returns all tasks in the specified task list.
       *
       * Create a request for the method "tasks.list".
       *
       * This request holds the parameters needed by the the tasks server.  After setting any optional
       * parameters, call the {@link List#execute()} method to invoke the remote operation. <p> {@link
       * List#initialize(AbstractGoogleClientRequest)} must be called to initialize this instance
       * immediately after invoking the constructor. </p>
       *
       * @param tasklist Task list identifier.
       * @since 1.13
       */
      protected List(String tasklist) {
        super(Tasks.this, "GET", REST_PATH, null, com.google.api.services.tasks.model.Tasks.class);
        this.tasklist = Preconditions.checkNotNull(tasklist, "Required parameter tasklist must be specified.");
      }

      @Override
      public com.google.api.client.http.HttpResponse executeUsingHead() throws java.io.IOException {
        return super.executeUsingHead();
      }

      @Override
      public com.google.api.client.http.HttpRequest buildHttpRequestUsingHead() throws java.io.IOException {
        return super.buildHttpRequestUsingHead();
      }

      @Override
      public List setAlt(String alt) {
        return (List) super.setAlt(alt);
      }

      @Override
      public List setFields(String fields) {
        return (List) super.setFields(fields);
      }

      @Override
      public List setKey(String key) {
        return (List) super.setKey(key);
      }

      @Override
      public List setOauthToken(String oauthToken) {
        return (List) super.setOauthToken(oauthToken);
      }

      @Override
      public List setPrettyPrint(Boolean prettyPrint) {
        return (List) super.setPrettyPrint(prettyPrint);
      }

      @Override
      public List setQuotaUser(String quotaUser) {
        return (List) super.setQuotaUser(quotaUser);
      }

      @Override
      public List setUserIp(String userIp) {
        return (List) super.setUserIp(userIp);
      }

      /** Task list identifier. */
      @com.google.api.client.util.Key
      private String tasklist;

      /** Task list identifier.
       */
      public String getTasklist() {
        return tasklist;
      }

      /** Task list identifier. */
      public List setTasklist(String tasklist) {
        this.tasklist = tasklist;
        return this;
      }

      /**
     * Upper bound for a task's due date (as a RFC 3339 timestamp) to filter by. Optional. The
     * default is not to filter by due date.
     */
      @com.google.api.client.util.Key
      private String dueMax;

      /** Upper bound for a task's due date (as a RFC 3339 timestamp) to filter by. Optional. The default is
     not to filter by due date.
       */
      public String getDueMax() {
        return dueMax;
      }

      /**
     * Upper bound for a task's due date (as a RFC 3339 timestamp) to filter by. Optional. The
     * default is not to filter by due date.
     */
      public List setDueMax(String dueMax) {
        this.dueMax = dueMax;
        return this;
      }

      /**
     * Flag indicating whether deleted tasks are returned in the result. Optional. The default is
     * False.
     */
      @com.google.api.client.util.Key
      private Boolean showDeleted;

      /** Flag indicating whether deleted tasks are returned in the result. Optional. The default is False.
       */
      public Boolean getShowDeleted() {
        return showDeleted;
      }

      /**
     * Flag indicating whether deleted tasks are returned in the result. Optional. The default is
     * False.
     */
      public List setShowDeleted(Boolean showDeleted) {
        this.showDeleted = showDeleted;
        return this;
      }

      /**
     * Lower bound for a task's last modification time (as a RFC 3339 timestamp) to filter by.
     * Optional. The default is not to filter by last modification time.
     */
      @com.google.api.client.util.Key
      private String updatedMin;

      /** Lower bound for a task's last modification time (as a RFC 3339 timestamp) to filter by. Optional.
     The default is not to filter by last modification time.
       */
      public String getUpdatedMin() {
        return updatedMin;
      }

      /**
     * Lower bound for a task's last modification time (as a RFC 3339 timestamp) to filter by.
     * Optional. The default is not to filter by last modification time.
     */
      public List setUpdatedMin(String updatedMin) {
        this.updatedMin = updatedMin;
        return this;
      }

      /**
     * Lower bound for a task's completion date (as a RFC 3339 timestamp) to filter by. Optional.
     * The default is not to filter by completion date.
     */
      @com.google.api.client.util.Key
      private String completedMin;

      /** Lower bound for a task's completion date (as a RFC 3339 timestamp) to filter by. Optional. The
     default is not to filter by completion date.
       */
      public String getCompletedMin() {
        return completedMin;
      }

      /**
     * Lower bound for a task's completion date (as a RFC 3339 timestamp) to filter by. Optional.
     * The default is not to filter by completion date.
     */
      public List setCompletedMin(String completedMin) {
        this.completedMin = completedMin;
        return this;
      }

      /** Maximum number of task lists returned on one page. Optional. The default is 100. */
      @com.google.api.client.util.Key
      private Long maxResults;

      /** Maximum number of task lists returned on one page. Optional. The default is 100.
       */
      public Long getMaxResults() {
        return maxResults;
      }

      /** Maximum number of task lists returned on one page. Optional. The default is 100. */
      public List setMaxResults(Long maxResults) {
        this.maxResults = maxResults;
        return this;
      }

      /**
     * Flag indicating whether completed tasks are returned in the result. Optional. The default is
     * True.
     */
      @com.google.api.client.util.Key
      private Boolean showCompleted;

      /** Flag indicating whether completed tasks are returned in the result. Optional. The default is True.
       */
      public Boolean getShowCompleted() {
        return showCompleted;
      }

      /**
     * Flag indicating whether completed tasks are returned in the result. Optional. The default is
     * True.
     */
      public List setShowCompleted(Boolean showCompleted) {
        this.showCompleted = showCompleted;
        return this;
      }

      /** Token specifying the result page to return. Optional. */
      @com.google.api.client.util.Key
      private String pageToken;

      /** Token specifying the result page to return. Optional.
       */
      public String getPageToken() {
        return pageToken;
      }

      /** Token specifying the result page to return. Optional. */
      public List setPageToken(String pageToken) {
        this.pageToken = pageToken;
        return this;
      }

      /**
     * Upper bound for a task's completion date (as a RFC 3339 timestamp) to filter by. Optional.
     * The default is not to filter by completion date.
     */
      @com.google.api.client.util.Key
      private String completedMax;

      /** Upper bound for a task's completion date (as a RFC 3339 timestamp) to filter by. Optional. The
     default is not to filter by completion date.
       */
      public String getCompletedMax() {
        return completedMax;
      }

      /**
     * Upper bound for a task's completion date (as a RFC 3339 timestamp) to filter by. Optional.
     * The default is not to filter by completion date.
     */
      public List setCompletedMax(String completedMax) {
        this.completedMax = completedMax;
        return this;
      }

      /**
     * Flag indicating whether hidden tasks are returned in the result. Optional. The default is
     * False.
     */
      @com.google.api.client.util.Key
      private Boolean showHidden;

      /** Flag indicating whether hidden tasks are returned in the result. Optional. The default is False.
       */
      public Boolean getShowHidden() {
        return showHidden;
      }

      /**
     * Flag indicating whether hidden tasks are returned in the result. Optional. The default is
     * False.
     */
      public List setShowHidden(Boolean showHidden) {
        this.showHidden = showHidden;
        return this;
      }

      /**
     * Lower bound for a task's due date (as a RFC 3339 timestamp) to filter by. Optional. The
     * default is not to filter by due date.
     */
      @com.google.api.client.util.Key
      private String dueMin;

      /** Lower bound for a task's due date (as a RFC 3339 timestamp) to filter by. Optional. The default is
     not to filter by due date.
       */
      public String getDueMin() {
        return dueMin;
      }

      /**
     * Lower bound for a task's due date (as a RFC 3339 timestamp) to filter by. Optional. The
     * default is not to filter by due date.
     */
      public List setDueMin(String dueMin) {
        this.dueMin = dueMin;
        return this;
      }

    }
    /**
     * Moves the specified task to another position in the task list. This can include putting it as a
     * child task under a new parent and/or move it to a different position among its sibling tasks.
     *
     * Create a request for the method "tasks.move".
     *
     * This request holds the parameters needed by the the tasks server.  After setting any optional
     * parameters, call the {@link Move#execute()} method to invoke the remote operation.
     *
     * @param tasklist Task list identifier.
     * @param task Task identifier.
     * @return the request
     */
    public Move move(String tasklist, String task) throws java.io.IOException {
      Move result = new Move(tasklist, task);
      initialize(result);
      return result;
    }

    public class Move extends TasksRequest<com.google.api.services.tasks.model.Task> {

      private static final String REST_PATH = "lists/{tasklist}/tasks/{task}/move";

      /**
       * Moves the specified task to another position in the task list. This can include putting it as a
       * child task under a new parent and/or move it to a different position among its sibling tasks.
       *
       * Create a request for the method "tasks.move".
       *
       * This request holds the parameters needed by the the tasks server.  After setting any optional
       * parameters, call the {@link Move#execute()} method to invoke the remote operation. <p> {@link
       * Move#initialize(AbstractGoogleClientRequest)} must be called to initialize this instance
       * immediately after invoking the constructor. </p>
       *
       * @param tasklist Task list identifier.
       * @param task Task identifier.
       * @since 1.13
       */
      protected Move(String tasklist, String task) {
        super(Tasks.this, "POST", REST_PATH, null, com.google.api.services.tasks.model.Task.class);
        this.tasklist = Preconditions.checkNotNull(tasklist, "Required parameter tasklist must be specified.");
        this.task = Preconditions.checkNotNull(task, "Required parameter task must be specified.");
      }

      @Override
      public Move setAlt(String alt) {
        return (Move) super.setAlt(alt);
      }

      @Override
      public Move setFields(String fields) {
        return (Move) super.setFields(fields);
      }

      @Override
      public Move setKey(String key) {
        return (Move) super.setKey(key);
      }

      @Override
      public Move setOauthToken(String oauthToken) {
        return (Move) super.setOauthToken(oauthToken);
      }

      @Override
      public Move setPrettyPrint(Boolean prettyPrint) {
        return (Move) super.setPrettyPrint(prettyPrint);
      }

      @Override
      public Move setQuotaUser(String quotaUser) {
        return (Move) super.setQuotaUser(quotaUser);
      }

      @Override
      public Move setUserIp(String userIp) {
        return (Move) super.setUserIp(userIp);
      }

      /** Task list identifier. */
      @com.google.api.client.util.Key
      private String tasklist;

      /** Task list identifier.
       */
      public String getTasklist() {
        return tasklist;
      }

      /** Task list identifier. */
      public Move setTasklist(String tasklist) {
        this.tasklist = tasklist;
        return this;
      }

      /** Task identifier. */
      @com.google.api.client.util.Key
      private String task;

      /** Task identifier.
       */
      public String getTask() {
        return task;
      }

      /** Task identifier. */
      public Move setTask(String task) {
        this.task = task;
        return this;
      }

      /**
     * New parent task identifier. If the task is moved to the top level, this parameter is omitted.
     * Optional.
     */
      @com.google.api.client.util.Key
      private String parent;

      /** New parent task identifier. If the task is moved to the top level, this parameter is omitted.
     Optional.
       */
      public String getParent() {
        return parent;
      }

      /**
     * New parent task identifier. If the task is moved to the top level, this parameter is omitted.
     * Optional.
     */
      public Move setParent(String parent) {
        this.parent = parent;
        return this;
      }

      /**
     * New previous sibling task identifier. If the task is moved to the first position among its
     * siblings, this parameter is omitted. Optional.
     */
      @com.google.api.client.util.Key
      private String previous;

      /** New previous sibling task identifier. If the task is moved to the first position among its
     siblings, this parameter is omitted. Optional.
       */
      public String getPrevious() {
        return previous;
      }

      /**
     * New previous sibling task identifier. If the task is moved to the first position among its
     * siblings, this parameter is omitted. Optional.
     */
      public Move setPrevious(String previous) {
        this.previous = previous;
        return this;
      }

    }
    /**
     * Updates the specified task. This method supports patch semantics.
     *
     * Create a request for the method "tasks.patch".
     *
     * This request holds the parameters needed by the the tasks server.  After setting any optional
     * parameters, call the {@link Patch#execute()} method to invoke the remote operation.
     *
     * @param tasklist Task list identifier.
     * @param task Task identifier.
     * @param content the {@link com.google.api.services.tasks.model.Task}
     * @return the request
     */
    public Patch patch(String tasklist, String task, com.google.api.services.tasks.model.Task content) throws java.io.IOException {
      Patch result = new Patch(tasklist, task, content);
      initialize(result);
      return result;
    }

    public class Patch extends TasksRequest<com.google.api.services.tasks.model.Task> {

      private static final String REST_PATH = "lists/{tasklist}/tasks/{task}";

      /**
       * Updates the specified task. This method supports patch semantics.
       *
       * Create a request for the method "tasks.patch".
       *
       * This request holds the parameters needed by the the tasks server.  After setting any optional
       * parameters, call the {@link Patch#execute()} method to invoke the remote operation. <p> {@link
       * Patch#initialize(AbstractGoogleClientRequest)} must be called to initialize this instance
       * immediately after invoking the constructor. </p>
       *
       * @param tasklist Task list identifier.
       * @param task Task identifier.
       * @param content the {@link com.google.api.services.tasks.model.Task}
       * @since 1.13
       */
      protected Patch(String tasklist, String task, com.google.api.services.tasks.model.Task content) {
        super(Tasks.this, "PATCH", REST_PATH, content, com.google.api.services.tasks.model.Task.class);
        this.tasklist = Preconditions.checkNotNull(tasklist, "Required parameter tasklist must be specified.");
        this.task = Preconditions.checkNotNull(task, "Required parameter task must be specified.");
      }

      @Override
      public Patch setAlt(String alt) {
        return (Patch) super.setAlt(alt);
      }

      @Override
      public Patch setFields(String fields) {
        return (Patch) super.setFields(fields);
      }

      @Override
      public Patch setKey(String key) {
        return (Patch) super.setKey(key);
      }

      @Override
      public Patch setOauthToken(String oauthToken) {
        return (Patch) super.setOauthToken(oauthToken);
      }

      @Override
      public Patch setPrettyPrint(Boolean prettyPrint) {
        return (Patch) super.setPrettyPrint(prettyPrint);
      }

      @Override
      public Patch setQuotaUser(String quotaUser) {
        return (Patch) super.setQuotaUser(quotaUser);
      }

      @Override
      public Patch setUserIp(String userIp) {
        return (Patch) super.setUserIp(userIp);
      }

      /** Task list identifier. */
      @com.google.api.client.util.Key
      private String tasklist;

      /** Task list identifier.
       */
      public String getTasklist() {
        return tasklist;
      }

      /** Task list identifier. */
      public Patch setTasklist(String tasklist) {
        this.tasklist = tasklist;
        return this;
      }

      /** Task identifier. */
      @com.google.api.client.util.Key
      private String task;

      /** Task identifier.
       */
      public String getTask() {
        return task;
      }

      /** Task identifier. */
      public Patch setTask(String task) {
        this.task = task;
        return this;
      }

    }
    /**
     * Updates the specified task.
     *
     * Create a request for the method "tasks.update".
     *
     * This request holds the parameters needed by the the tasks server.  After setting any optional
     * parameters, call the {@link Update#execute()} method to invoke the remote operation.
     *
     * @param tasklist Task list identifier.
     * @param task Task identifier.
     * @param content the {@link com.google.api.services.tasks.model.Task}
     * @return the request
     */
    public Update update(String tasklist, String task, com.google.api.services.tasks.model.Task content) throws java.io.IOException {
      Update result = new Update(tasklist, task, content);
      initialize(result);
      return result;
    }

    public class Update extends TasksRequest<com.google.api.services.tasks.model.Task> {

      private static final String REST_PATH = "lists/{tasklist}/tasks/{task}";

      /**
       * Updates the specified task.
       *
       * Create a request for the method "tasks.update".
       *
       * This request holds the parameters needed by the the tasks server.  After setting any optional
       * parameters, call the {@link Update#execute()} method to invoke the remote operation. <p> {@link
       * Update#initialize(AbstractGoogleClientRequest)} must be called to initialize this instance
       * immediately after invoking the constructor. </p>
       *
       * @param tasklist Task list identifier.
       * @param task Task identifier.
       * @param content the {@link com.google.api.services.tasks.model.Task}
       * @since 1.13
       */
      protected Update(String tasklist, String task, com.google.api.services.tasks.model.Task content) {
        super(Tasks.this, "PUT", REST_PATH, content, com.google.api.services.tasks.model.Task.class);
        this.tasklist = Preconditions.checkNotNull(tasklist, "Required parameter tasklist must be specified.");
        this.task = Preconditions.checkNotNull(task, "Required parameter task must be specified.");
      }

      @Override
      public Update setAlt(String alt) {
        return (Update) super.setAlt(alt);
      }

      @Override
      public Update setFields(String fields) {
        return (Update) super.setFields(fields);
      }

      @Override
      public Update setKey(String key) {
        return (Update) super.setKey(key);
      }

      @Override
      public Update setOauthToken(String oauthToken) {
        return (Update) super.setOauthToken(oauthToken);
      }

      @Override
      public Update setPrettyPrint(Boolean prettyPrint) {
        return (Update) super.setPrettyPrint(prettyPrint);
      }

      @Override
      public Update setQuotaUser(String quotaUser) {
        return (Update) super.setQuotaUser(quotaUser);
      }

      @Override
      public Update setUserIp(String userIp) {
        return (Update) super.setUserIp(userIp);
      }

      /** Task list identifier. */
      @com.google.api.client.util.Key
      private String tasklist;

      /** Task list identifier.
       */
      public String getTasklist() {
        return tasklist;
      }

      /** Task list identifier. */
      public Update setTasklist(String tasklist) {
        this.tasklist = tasklist;
        return this;
      }

      /** Task identifier. */
      @com.google.api.client.util.Key
      private String task;

      /** Task identifier.
       */
      public String getTask() {
        return task;
      }

      /** Task identifier. */
      public Update setTask(String task) {
        this.task = task;
        return this;
      }

    }

  }

  /**
   * Builder for {@link Tasks}.
   *
   * <p>
   * Implementation is not thread-safe.
   * </p>
   *
   * @since 1.3.0
   */
  public static final class Builder extends AbstractGoogleJsonClient.Builder {

    /**
     * Returns an instance of a new builder.
     *
     * @param transport HTTP transport
     * @param jsonFactory JSON factory
     * @param httpRequestInitializer HTTP request initializer or {@code null} for none
     * @since 1.7
     */
    public Builder(HttpTransport transport, JsonFactory jsonFactory,
        HttpRequestInitializer httpRequestInitializer) {
      super(
          transport,
          jsonFactory,
          DEFAULT_ROOT_URL,
          DEFAULT_SERVICE_PATH,
          httpRequestInitializer,
          false);
    }

    /** Builds a new instance of {@link Tasks}. */
    @Override
    public Tasks build() {
      return new Tasks(getTransport(),
          getHttpRequestInitializer(),
          getRootUrl(),
          getServicePath(),
          getObjectParser(),
          getGoogleClientRequestInitializer(),
          getApplicationName(),
          getSuppressPatternChecks());
    }

    @Override
    public Builder setRootUrl(String rootUrl) {
      return (Builder) super.setRootUrl(rootUrl);
    }

    @Override
    public Builder setServicePath(String servicePath) {
      return (Builder) super.setServicePath(servicePath);
    }

    @Override
    public Builder setHttpRequestInitializer(HttpRequestInitializer httpRequestInitializer) {
      return (Builder) super.setHttpRequestInitializer(httpRequestInitializer);
    }

    @Override
    public Builder setApplicationName(String applicationName) {
      return (Builder) super.setApplicationName(applicationName);
    }

    @Override
    public Builder setSuppressPatternChecks(boolean suppressPatternChecks) {
      return (Builder) super.setSuppressPatternChecks(suppressPatternChecks);
    }

    /**
     * Set the {@link TasksRequestInitializer}.
     *
     * @since 1.12
     */
    public Builder setTasksRequestInitializer(
        TasksRequestInitializer tasksRequestInitializer) {
      return (Builder) super.setGoogleClientRequestInitializer(tasksRequestInitializer);
    }

    @Override
    public Builder setGoogleClientRequestInitializer(
        GoogleClientRequestInitializer googleClientRequestInitializer) {
      return (Builder) super.setGoogleClientRequestInitializer(googleClientRequestInitializer);
    }
  }
}
